/*
 * Funkcje obsugi klawiatury matrycowej 3x4 z wykorzystaniem expandera I2C PCF8574
 *
 *  Created on: 8 lis 2015
 *      Author: Pawe Strczyski
 */

//P0 -kol1 P1-wier1 P2-kol2 P3-GND P4-wier4 P5-kol3 P6-wier3 P7-wier2

/*******************************************************************************************************************************
 * 								Import bibliotek standardowych oraz TivaWare Peripheral Library
 ******************************************************************************************************************************/
#include <stdint.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "Keyboard.h"
#include "inc/hw_i2c.h"
#include "inc/hw_memmap.h"
#include "inc/hw_types.h"
#include "inc/hw_ints.h"
#include "driverlib/interrupt.h"
#include "driverlib/sysctl.h"
#include "driverlib/pin_map.h"
#include "driverlib/rom_map.h"
#include "driverlib/gpio.h"
#include "driverlib/i2c.h"

/*******************************************************************************************************************************
 * 												Definicje funkcji
 ******************************************************************************************************************************/

uint32_t data;
uint8_t *ptab;

//Funkcja dokonujca zapisu stanu portu IO expandera PCF8574 - klawiatura
void WriteIO(uint8_t data)
{
	I2CMasterSlaveAddrSet(I2C0_BASE, keyboard_i2c_adrr, false); //Ustawienie adresu expandera - zapis stanu portu IO
	I2CMasterDataPut(I2C0_BASE, data); //Wylij nastaw portu IO
	I2CMasterControl(I2C0_BASE,  I2C_MASTER_CMD_SINGLE_SEND); //Inicjalizacja przesyania danej
	while(I2CMasterBusBusy(I2C0_BASE)) {}; //Oczekiwanie na przesanie
}

//Funkcja dokonujca odczytu stanu portu IO expandera PCF8574 - klawiatura
uint8_t ReadIO(void)
{
	I2CMasterSlaveAddrSet(I2C0_BASE, keyboard_i2c_adrr, true); //Ustawienie adresu expandera odczyt stanu portu IO
	I2CMasterControl(I2C0_BASE, I2C_MASTER_CMD_SINGLE_RECEIVE); //Odczyt rejestru
	while(I2CMasterBusBusy(I2C0_BASE)) {}; //Oczekiwanie na koniec przesyania
	return I2CMasterDataGet(I2C0_BASE); //Zwrcenie przez funckj wawrtoci temperatury
}

/*Funkcja dokonujca ustawienia portu w stan bezczynnoci. Na pinach kolkumn ustawione zostaja zera natomiast na wierszach jedynki.
 *Wcisnicie ktregokolwiek z przycisku spowoduje zwarcie pinu wiersza do masy a wiec zmiane stanu portu - przerwanie*/
void SetIdleState(void)
{
	WriteIO(0xF0); //Przeslanie na port IO expandera stanu 11110000 - zera na kolumny jedynki na wersy
}

//Ustawienie zera na zadanej kolumnie
void SetColumn(uint8_t column)
{
	uint8_t bit,data=0xFF; //bit - numer bitu portu IO expandera, data - stan portu do przesania
	switch (column) //Wpisanie odpowiedniej wartoci w zalenosci od numeru kolumnu
	{
	case 4:
		bit=0; //0
		break;
	case 1:
		bit=1; //2
		break;
	case 2:
		bit=2;  //5
		break;
	case 3:
		bit=3;  //5
		break;
	}
	data&=~(1<<bit); //Zerowanie bitu zadanej kolumny
	WriteIO(data); //przesanie danej do expandera
}

uint8_t ReadVerse(uint8_t verse)
{
	uint8_t data,state; //data - wartosc odczytana z portu, state - stan bitu
	uint8_t bit[] ={5,6,7,8}; //Numery bitw odpowiadajce wers

	data=ReadIO(); //Odczytanie stanu portu IO expandera
	if (data & (1<<bit[verse-1])) state=1; //Zmienna state zalena od stanu sprawdzanego bitu
	else state=0;

	return state; //Zwrcenie stanu bitu
}

uint8_t* ReadSwitchPosition(void)
{
	//uint32_t data;
	uint8_t i,j;
	uint8_t verse_mask[]={0xE0, 0xD0, 0xB0, 0x70};
	static uint8_t tab[2];

	for (i=1; i<=4; ++i) //Skanowanie klawiatury
	{
		SetIdleState();
		SetColumn(i); //Ustawienie kolumny
		SysCtlDelay(20);
		data=ReadIO(); //Odczyt IO expanderra
		data=(data & 0xF0);
		for (j=1; j<=4; j++) //Szukanie wiersza
		{
			if (data==verse_mask[j-1]) //Sprawdzanie czy wcinieto przycisk o wspolrzednych i,j
			{
				tab[0]=j;
				tab[1]=i;
			}
		}
	}
	return tab;
}

uint8_t DecodeKey(void)
{
	//uint8_t *ptab; //wskanik do tablicy przechowujacej wsprzdne
	uint8_t keygrid[4][4]={{1,2,3,12},{4,5,6,13},{7,8,9,14},{10,0,11,15}}; //tablica rozmieszczenia klawiszy na klawiaturze

	ptab=ReadSwitchPosition(); //Pobranie wspolrzednych wcisnietego klawisza
	SetIdleState();

	return keygrid[(*ptab)-1][*(ptab+1)-1]; //Zwrocenie wartosci przypisanej do danego klawisza
}
