/*
 * Funkcje inicjalizujce prac peryferiw mikrokontrolera
 *
 *  Created on: 7 lis 2015
 *      Author: Pawe Strczyski
 */

/*******************************************************************************************************************************
 * 								Import bibliotek standardowych oraz TivaWare Peripheral Library
 ******************************************************************************************************************************/
#include <stdint.h>
#include <stdbool.h>
#include <math.h>
#include "Init.h"
#include "Stepper.h"
#include "inc/hw_memmap.h"
#include "inc/hw_types.h"
#include "inc/hw_i2c.h"
#include "inc/hw_gpio.h"
#include "inc/hw_uart.h"
#include "inc/hw_ints.h"
#include "utils/uartstdio.h"
#include "driverlib/interrupt.h"
#include "driverlib/sysctl.h"
#include "driverlib/gpio.h"
#include "driverlib/timer.h"
#include "driverlib/pwm.h"
#include "driverlib/pin_map.h"
#include "driverlib/rom_map.h"
#include "driverlib/adc.h"
#include "driverlib/i2c.h"
#include "driverlib/qei.h"
#include "driverlib/uart.h"

#define UART_BAUD 115200 //Prdko transmisji UART
#define F_CPU 16000000 //Czstotliwo rezonatora kwarcowego

extern void PortP2IntHandler(void);
extern void PortJIntHandler(void);
/******************************************************************************************************************************
* 												Zmienne globalne
******************************************************************************************************************************/
uint32_t ui32SysClkFreq; //Czstotliwo systemowa
/*******************************************************************************************************************************
 * 												Definicje funkcji
 ******************************************************************************************************************************/
void InitPWMOutput(void) //Wyjcia PWM - Wentylator, Grzejnik
{
	SysCtlPeripheralEnable(SYSCTL_PERIPH_PWM0); //Wczenie zegara dla moduu PWM0
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOF); //Wczenie moduu portu F - GPIOF
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOG); //Wczenie moduu portu g - GPIOG
	PWMClockSet(PWM0_BASE,PWM_SYSCLK_DIV_64); //Ustawienie preskalera zegara PWM0 na 64 120Mhz/64
	GPIOPinConfigure(GPIO_PF3_M0PWM3); //Konfiguracja PWM na wyjciu PF3
	GPIOPinConfigure(GPIO_PG0_M0PWM4); //Konfiguracja PWM na wyjciu PG0
	GPIOPinTypePWM(GPIO_PORTF_BASE, GPIO_PIN_3); //Ustawienie PF3 w tryb PWM - Wentylator
	GPIOPinTypePWM(GPIO_PORTG_BASE, GPIO_PIN_0); //Ustawienie PG0 w tryb PWM - Grzejnik
	PWMGenConfigure(PWM0_BASE, PWM_GEN_1, PWM_GEN_MODE_DOWN); //Konfiguracja generatora 1 w tryb CountDown
	PWMGenConfigure(PWM0_BASE, PWM_GEN_2, PWM_GEN_MODE_DOWN); //Konfiguracja generatora 2 w tryb CountDown
	PWMGenPeriodSet(PWM0_BASE, PWM_GEN_1, 1875); //Ustawienie czstotliwoci generatora 1 PWM na 100Hz
	PWMGenPeriodSet(PWM0_BASE, PWM_GEN_2, 1875); //Ustawienie czstotliwoci generatora 2 PWM na 100Hz
	PWMPulseWidthSet(PWM0_BASE, PWM_OUT_3, 18748); //Ustawienie wypenienia 100% dla wyjcia 3 moduu PWM0 - PF3
	PWMPulseWidthSet(PWM0_BASE, PWM_OUT_4, 18748); //Ustawienie wypenienia 100% dla wyjcia 4 moduu PWM0 - PG0
	PWMOutputState(PWM0_BASE, PWM_OUT_3_BIT, true); //Konfiguracja stanu wyjcia M0PWM3
	PWMOutputState(PWM0_BASE, PWM_OUT_4_BIT, true); //Konfiguracja stanu wyjcia M0PWM4
	//PWMGenEnable(PWM0_BASE, PWM_GEN_1 | PWM_GEN_2 ); //Wczenie  generatorw 1 i 2 moduu PWM0
	PWMGenEnable(PWM0_BASE, PWM_GEN_1);
	PWMGenEnable(PWM0_BASE, PWM_GEN_2);
}

void InitI2C(void)
{
	SysCtlPeripheralEnable(SYSCTL_PERIPH_I2C0); //Wczenie zegara dla moduu I2C0
	SysCtlPeripheralReset(SYSCTL_PERIPH_I2C0); //Reset moduu I2C0
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOB); ///Wczenie zegara do portu B
	GPIOPinConfigure(GPIO_PB2_I2C0SCL); //Konfiguracja pinu PB2 jako sygna zegara I2C - SCL
	GPIOPinConfigure(GPIO_PB3_I2C0SDA); //Konfiguracja pinu PB3 jako sygna danych I2C - SDA
	GPIOPinTypeI2CSCL(GPIO_PORTB_BASE, GPIO_PIN_2); //Ustawienie SCL na pinie PB2
	GPIOPinTypeI2C(GPIO_PORTB_BASE, GPIO_PIN_3); //Ustawienie SDA na pinie PB3
	I2CMasterInitExpClk(I2C0_BASE, SysCtlClockGet(), true); //Ustawienie zegaru sytsemowego dla I2C, prdko transmisji 400kbps
	//HWREG(I2C0_BASE + I2C_O_FIFOCTL) = 80008000; //Czyszczenie I2C FIFO

}


void InitADC(void) //Wejcia ADC - napicie z kanau 0 - temperatura - termistor
{
	SysCtlPeripheralEnable(SYSCTL_PERIPH_ADC0); //Wczenie zegara dla moduu ADC0
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOE); ///Wczenie zegara do portu E
	GPIOPinTypeADC(GPIO_PORTE_BASE, GPIO_PIN_3); //Ustawienie PE3 w tryb ADC
	ADCHardwareOversampleConfigure(ADC0_BASE,64); //Sprztowe urednianie pomiaru
	ADCSoftwareOversampleConfigure(ADC0_BASE,1,8); //Programowe urednianie pomiaru
	ADCSequenceConfigure(ADC0_BASE, 1, ADC_TRIGGER_PROCESSOR, 0); //Ustawienie sekwencera 1 przetwornika ADC0
	ADCSequenceStepConfigure(ADC0_BASE, 1, 0, ADC_CTL_CH0 | ADC_CTL_IE | ADC_CTL_END); //Pomiar napiecia z kanau 0 - termistor
	ADCSequenceEnable(ADC0_BASE, 1); //Uruchomienie sekwencera 1
}

void InitUART(void) //Inicjalizacja moduu UART0
{
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOA); //Wczenie zegara do portu A
	GPIOPinConfigure(GPIO_PA0_U0RX); //Koniguracja pinu odbiorczego RX
	GPIOPinConfigure(GPIO_PA1_U0TX); //Koniguracja pinu nadawczego TX
	SysCtlPeripheralEnable(SYSCTL_PERIPH_UART0); //Wczenie zegara do moduu UART0
	GPIOPinTypeUART(GPIO_PORTA_BASE, GPIO_PIN_0 | GPIO_PIN_1); //PA0 i PA1 jako piny UART
	UARTClockSourceSet(UART0_BASE, UART_CLOCK_PIOSC);
	IntMasterEnable(); //Wczenie systemw przerwa
	IntEnable(INT_UART0); //Wczenie przerwa od moduu UART0
	UARTIntEnable(UART0_BASE, UART_INT_RX | UART_INT_RT); //Ustawienie przerwania od UART0
	UARTStdioConfig(0,UART_BAUD,F_CPU); //Konfiguracja moduu UART0
};

void InitTimer(void)
{
	//Konifiguracja Timera 0 licznik A
	SysCtlPeripheralEnable(SYSCTL_PERIPH_TIMER0); //Wczenie zegara dla moduu TIMER0
	TimerConfigure(TIMER0_BASE, TIMER_CFG_PERIODIC); //Konfiguracja timera0 w tryb Full-width periodic timer
	TimerLoadSet(TIMER0_BASE, TIMER_A, ((ui32SysClkFreq/2)-1)/2); //Zaadowanie maksymalnej wartoci do timera
	IntEnable(INT_TIMER0A); //Uruchomienie przerwania od TIMER0A
	TimerIntEnable(TIMER0_BASE,TIMER_TIMA_TIMEOUT); //Wczenie indywidualnego rda przerwania od timera
	IntMasterEnable(); //Wczenie systemu przerwa
	TimerEnable(TIMER0_BASE, TIMER_A); //Uruchomienie licznika 0A
};

void InitQEI(void)
{
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOL); //Wczenie portu L
	SysCtlPeripheralEnable(SYSCTL_PERIPH_QEI0);
	GPIOPinConfigure(GPIO_PL1_PHA0);
	GPIOPinConfigure(GPIO_PL2_PHB0);
	GPIOPinTypeQEI(GPIO_PORTL_BASE, GPIO_PIN_1);  //Ph A
	GPIOPinTypeQEI(GPIO_PORTL_BASE, GPIO_PIN_2);  //Ph B
	QEIConfigure(QEI0_BASE,(QEI_CONFIG_CAPTURE_A_B | QEI_CONFIG_NO_RESET | QEI_CONFIG_QUADRATURE | QEI_CONFIG_NO_SWAP), 4096);
	QEIEnable(QEI0_BASE);
	QEIPositionSet(QEI0_BASE, 0);
};

void InitGPIO(void)
{
	//Konfiguracja pinu do obsugi przerwania zdarzeniowego dzialania klawiatury
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOP); //Wlaczenie portu P
	GPIOPinTypeGPIOInput(GPIO_PORTP_BASE, GPIO_PIN_2); //Konfiguracja pinu PP2 jako wejcie
	GPIOPadConfigSet(GPIO_PORTP_BASE, GPIO_PIN_2, GPIO_STRENGTH_2MA, GPIO_PIN_TYPE_STD_WPU); //Wlaczenie wewnetrznego rezystora podciagajacego Pull-up
	GPIOIntRegister(GPIO_PORTP_BASE, PortP2IntHandler); //Rejstracja funkcji obslugujacej przerwanie od pinu P2
	GPIOIntTypeSet(GPIO_PORTP_BASE, GPIO_PIN_2, GPIO_FALLING_EDGE ); //Konfigracja wyzwalania przerwania opadajacym zboczem
	GPIOIntEnable(GPIO_PORTP_BASE, GPIO_PIN_2);  //Uruchomienie obslugi przerwania od pinu PP2

	//Konfiguracja przyciskw uytkownika - na Lunchpadzie
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOJ); //Wlaczenie portu J
	GPIOPinTypeGPIOInput(GPIO_PORTJ_BASE, GPIO_PIN_0 | GPIO_PIN_1 ); //Konfiguracja pinw PJ0 i PJ1 jako wejcia
	GPIOPadConfigSet(GPIO_PORTJ_BASE, GPIO_PIN_0 | GPIO_PIN_1 , GPIO_STRENGTH_2MA, GPIO_PIN_TYPE_STD_WPU); //Wlaczenie wewnetrznego rezystora podciagajacego Pull-up
	GPIOIntRegister(GPIO_PORTJ_BASE, PortJIntHandler); //Rejstracja funkcji obslugujacej przerwanie od portu J
	GPIOIntTypeSet(GPIO_PORTJ_BASE, GPIO_PIN_0 | GPIO_PIN_1,  GPIO_FALLING_EDGE );  //Konfigracja wyzwalania przerwania opadajacym zboczem
	GPIOIntEnable(GPIO_PORTJ_BASE, GPIO_PIN_0 | GPIO_PIN_1);  //Uruchomienie obslugi przerwania od pinw PJ0 i PJ1

	IntMasterEnable(); //Wczenie systemu przerwa
}

void InitModule(void)
{
	ui32SysClkFreq=SysCtlClockFreqSet((SYSCTL_XTAL_25MHZ | SYSCTL_OSC_MAIN | SYSCTL_USE_PLL | SYSCTL_CFG_VCO_480), 12000000); //Konfiguracja zegara
	InitI2C();
	InitPWMOutput();
	InitGPIO();
	InitUART();
	InitTimer();
	InitADC();
	InitQEI();
	InitStepper();
}
